@@ -3,11 +3,28 @@
 # Date: 2020-11-29 17:48
 import json
 from typing import Union, List, Optional, Dict, Any
+from urllib.error import HTTPError
 from urllib.parse import urlencode
 from urllib.request import Request, urlopen
-
 from hanlp_common.document import Document
 
+try:
+    # noinspection PyUnresolvedReferences
+    import requests
+
+
+    def _post(url, form: Dict[str, Any], headers: Dict[str, Any], timeout=5) -> str:
+        response = requests.post(url, json=form, headers=headers, timeout=timeout)
+        if response.status_code != 200:
+            raise HTTPError(url, response.status_code, response.text, response.headers, None)
+        return response.text
+except ImportError:
+    def _post(url, form: Dict[str, Any], headers: Dict[str, Any], timeout=5) -> str:
+        request = Request(url, json.dumps(form).encode())
+        for k, v in headers.items():
+            request.add_header(k, v)
+        return urlopen(request, timeout=timeout).read().decode()
+
 
 class HanLPClient(object):
 
@@ -97,7 +114,7 @@ class HanLPClient(object):
         return urlopen(request, timeout=self._timeout).read().decode()
 
     def _send_post_json(self, url, form: Dict[str, Any]):
-        return json.loads(self._send_post(url, form))
+        return json.loads(_post(url, form, {'Authorization': f'Basic {self._auth}'}, self._timeout))
 
     def _send_get(self, url, form: Dict[str, Any]):
         request = Request(url + '?' + urlencode(form))
