@@ -5,14 +5,18 @@ from hanlp_restful import HanLPClient
 
 
 def main():
-    _test_raw_text()
+    HanLP = HanLPClient('https://hanlp.hankcs.com/api', auth=None)  # Fill in your auth
+    doc = HanLP.parse('2021年HanLPv2.1为生产环境带来次世代最先进的多语种NLP技术。阿婆主来到北京立方庭参观自然语义科技公司。')
+    print(doc)
+    # doc.pretty_print(ner='ner/msra')
+    # _test_raw_text()
     # _test_sents()
     # _test_tokens()
 
 
 def _test_raw_text():
     HanLP = HanLPClient('https://hanlp.hankcs.com/api')
-    text = '2021年HanLPv2.1为生产环境带来次世代最先进的多语种NLP技术。英首相与特朗普通电话讨论华为与苹果公司。'
+    text = ' '
     doc = HanLP.parse(text)
     print(doc)
     doc.pretty_print(ner='ner/pku')
